import storage from '@/utils/storage'
import constant from '@/utils/constant'
import {
	getInfo,
	login,
	logout
} from '@/api/login'
import {
	getIsLogin,
	getToken,
	removeToken,
	setIsLogin,
	setToken
} from '@/utils/auth'
import {
	currentUrl
} from '@/utils/getUrl'
import {
	wxLogin
} from "../../api/system/user";

const baseUrl = currentUrl
const user = {
	state: {
		accessToken: uni.getStorageSync("token") || "",
		userInfo: uni.getStorageSync("baseInfo") ? JSON.parse(uni.getStorageSync("baseInfo")) : {}
	},

	mutations: {
		// 设置token
		setAccessToken(state, token) {
			state.accessToken = token;
		},

		// 设置用户信息
		setUserInfo(state, userInfo) {
			state.userInfo = userInfo;
		}
	},

	actions: {
		login(context) {
			uni.login({
				success: (res) => {
					const code = res.code
					wxLogin({
						code
					}).then(res => {
						if (res.code === 200) {
							uni.setStorageSync("token", res.data.token)
							uni.setStorageSync("baseInfo", JSON.stringify(res.data.userInfo))
							context.commit('setAccessToken', res.data.token);
							context.commit('setUserInfo', res.data.userInfo);
							setIsLogin("isLogin", true);

							if (!res.data.userInfo.userName || !res.data.userInfo.userImage || !res.data.userInfo.userTelephone) {
								uni.navigateTo({
									url: "/pages/login/wxUserInfo"
								})
							}else {
								uni.navigateBack(-1)
							}
						}
					})
				}
			})
		}
	}
}

export default user